predict.l1ce: Predict Method for `l1ce' Objects
Description
Extracts the fitted values from a l1ce object and returns a matrix of
predictions.Usage
predict.l1ce(object, newdata, type=c("response"), se.fit = FALSE, ...)Value
a vector of predictions.Warning
predict can produce incorrect predictions when the newdata
argument is used if the formula in object involves
transformations, such as poly(Age, 3) or sqrt(Age - min(Age)).Details
This function is a method for the generic function predict
for class "l1ce". It can be invoked by calling predict
for an object of the appropriate class, or directly by
calling predict.l1ce regardless of the class of the object.